@@ -3,7 +3,7 @@
 #' @noRd
 app_bsky_feed_describe_feed_generator <- function(.token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.describeFeedGenerator",
+    name = "bsky.social/xrpc/app.bsky.feed.describeFeedGenerator",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -19,7 +19,7 @@ app_bsky_feed_describe_feed_generator <- function(.token = NULL, .return = c("js
 #' @noRd
 app_bsky_feed_get_actor_feeds <- function(actor, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getActorFeeds",
+    name = "bsky.social/xrpc/app.bsky.feed.getActorFeeds",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -35,7 +35,7 @@ app_bsky_feed_get_actor_feeds <- function(actor, limit = NULL, cursor = NULL, .t
 #' @noRd
 app_bsky_feed_get_actor_likes <- function(actor, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getActorLikes",
+    name = "bsky.social/xrpc/app.bsky.feed.getActorLikes",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -51,7 +51,7 @@ app_bsky_feed_get_actor_likes <- function(actor, limit = NULL, cursor = NULL, .t
 #' @noRd
 app_bsky_feed_get_author_feed <- function(actor, limit = NULL, cursor = NULL, filter = NULL, includePins = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getAuthorFeed",
+    name = "bsky.social/xrpc/app.bsky.feed.getAuthorFeed",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -67,7 +67,7 @@ app_bsky_feed_get_author_feed <- function(actor, limit = NULL, cursor = NULL, fi
 #' @noRd
 app_bsky_feed_get_feed <- function(feed, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getFeed",
+    name = "bsky.social/xrpc/app.bsky.feed.getFeed",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -83,7 +83,7 @@ app_bsky_feed_get_feed <- function(feed, limit = NULL, cursor = NULL, .token = N
 #' @noRd
 app_bsky_feed_get_feed_generator <- function(feed, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getFeedGenerator",
+    name = "bsky.social/xrpc/app.bsky.feed.getFeedGenerator",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -99,7 +99,7 @@ app_bsky_feed_get_feed_generator <- function(feed, .token = NULL, .return = c("j
 #' @noRd
 app_bsky_feed_get_feed_generators <- function(feeds, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getFeedGenerators",
+    name = "bsky.social/xrpc/app.bsky.feed.getFeedGenerators",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -115,7 +115,7 @@ app_bsky_feed_get_feed_generators <- function(feeds, .token = NULL, .return = c(
 #' @noRd
 app_bsky_feed_get_feed_skeleton <- function(feed, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getFeedSkeleton",
+    name = "bsky.social/xrpc/app.bsky.feed.getFeedSkeleton",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -131,7 +131,7 @@ app_bsky_feed_get_feed_skeleton <- function(feed, limit = NULL, cursor = NULL, .
 #' @noRd
 app_bsky_feed_get_likes <- function(uri, cid = NULL, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getLikes",
+    name = "bsky.social/xrpc/app.bsky.feed.getLikes",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -147,7 +147,7 @@ app_bsky_feed_get_likes <- function(uri, cid = NULL, limit = NULL, cursor = NULL
 #' @noRd
 app_bsky_feed_get_list_feed <- function(list, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getListFeed",
+    name = "bsky.social/xrpc/app.bsky.feed.getListFeed",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -163,7 +163,7 @@ app_bsky_feed_get_list_feed <- function(list, limit = NULL, cursor = NULL, .toke
 #' @noRd
 app_bsky_feed_get_post_thread <- function(uri, depth = NULL, parentHeight = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getPostThread",
+    name = "bsky.social/xrpc/app.bsky.feed.getPostThread",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -179,7 +179,7 @@ app_bsky_feed_get_post_thread <- function(uri, depth = NULL, parentHeight = NULL
 #' @noRd
 app_bsky_feed_get_posts <- function(uris, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getPosts",
+    name = "bsky.social/xrpc/app.bsky.feed.getPosts",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -195,7 +195,7 @@ app_bsky_feed_get_posts <- function(uris, .token = NULL, .return = c("json", "re
 #' @noRd
 app_bsky_feed_get_quotes <- function(uri, cid = NULL, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getQuotes",
+    name = "bsky.social/xrpc/app.bsky.feed.getQuotes",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -211,7 +211,7 @@ app_bsky_feed_get_quotes <- function(uri, cid = NULL, limit = NULL, cursor = NUL
 #' @noRd
 app_bsky_feed_get_reposted_by <- function(uri, cid = NULL, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getRepostedBy",
+    name = "bsky.social/xrpc/app.bsky.feed.getRepostedBy",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -227,7 +227,7 @@ app_bsky_feed_get_reposted_by <- function(uri, cid = NULL, limit = NULL, cursor
 #' @noRd
 app_bsky_feed_get_suggested_feeds <- function(limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getSuggestedFeeds",
+    name = "bsky.social/xrpc/app.bsky.feed.getSuggestedFeeds",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -243,7 +243,7 @@ app_bsky_feed_get_suggested_feeds <- function(limit = NULL, cursor = NULL, .toke
 #' @noRd
 app_bsky_feed_get_timeline <- function(algorithm = NULL, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.getTimeline",
+    name = "bsky.social/xrpc/app.bsky.feed.getTimeline",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -259,7 +259,7 @@ app_bsky_feed_get_timeline <- function(algorithm = NULL, limit = NULL, cursor =
 #' @noRd
 app_bsky_feed_search_posts <- function(q, sort = NULL, since = NULL, until = NULL, mentions = NULL, author = NULL, lang = NULL, domain = NULL, url = NULL, tag = NULL, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.searchPosts",
+    name = "bsky.social/xrpc/app.bsky.feed.searchPosts",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -275,7 +275,7 @@ app_bsky_feed_search_posts <- function(q, sort = NULL, since = NULL, until = NUL
 #' @noRd
 app_bsky_feed_send_interactions <- function(interactions, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.feed.sendInteractions",
+    name = "bsky.social/xrpc/app.bsky.feed.sendInteractions",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
