@@ -3,7 +3,7 @@
 #' @noRd
 app_bsky_graph_get_actor_starter_packs <- function(actor, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getActorStarterPacks",
+    name = "bsky.social/xrpc/app.bsky.graph.getActorStarterPacks",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -19,7 +19,7 @@ app_bsky_graph_get_actor_starter_packs <- function(actor, limit = NULL, cursor =
 #' @noRd
 app_bsky_graph_get_blocks <- function(limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getBlocks",
+    name = "bsky.social/xrpc/app.bsky.graph.getBlocks",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -35,7 +35,7 @@ app_bsky_graph_get_blocks <- function(limit = NULL, cursor = NULL, .token = NULL
 #' @noRd
 app_bsky_graph_get_followers <- function(actor, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getFollowers",
+    name = "bsky.social/xrpc/app.bsky.graph.getFollowers",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -51,7 +51,7 @@ app_bsky_graph_get_followers <- function(actor, limit = NULL, cursor = NULL, .to
 #' @noRd
 app_bsky_graph_get_follows <- function(actor, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getFollows",
+    name = "bsky.social/xrpc/app.bsky.graph.getFollows",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -67,7 +67,7 @@ app_bsky_graph_get_follows <- function(actor, limit = NULL, cursor = NULL, .toke
 #' @noRd
 app_bsky_graph_get_known_followers <- function(actor, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getKnownFollowers",
+    name = "bsky.social/xrpc/app.bsky.graph.getKnownFollowers",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -83,7 +83,7 @@ app_bsky_graph_get_known_followers <- function(actor, limit = NULL, cursor = NUL
 #' @noRd
 app_bsky_graph_get_list <- function(list, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getList",
+    name = "bsky.social/xrpc/app.bsky.graph.getList",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -99,7 +99,7 @@ app_bsky_graph_get_list <- function(list, limit = NULL, cursor = NULL, .token =
 #' @noRd
 app_bsky_graph_get_list_blocks <- function(limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getListBlocks",
+    name = "bsky.social/xrpc/app.bsky.graph.getListBlocks",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -115,7 +115,7 @@ app_bsky_graph_get_list_blocks <- function(limit = NULL, cursor = NULL, .token =
 #' @noRd
 app_bsky_graph_get_list_mutes <- function(limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getListMutes",
+    name = "bsky.social/xrpc/app.bsky.graph.getListMutes",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -131,7 +131,7 @@ app_bsky_graph_get_list_mutes <- function(limit = NULL, cursor = NULL, .token =
 #' @noRd
 app_bsky_graph_get_lists <- function(actor, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getLists",
+    name = "bsky.social/xrpc/app.bsky.graph.getLists",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -147,7 +147,7 @@ app_bsky_graph_get_lists <- function(actor, limit = NULL, cursor = NULL, .token
 #' @noRd
 app_bsky_graph_get_mutes <- function(limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getMutes",
+    name = "bsky.social/xrpc/app.bsky.graph.getMutes",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -163,7 +163,7 @@ app_bsky_graph_get_mutes <- function(limit = NULL, cursor = NULL, .token = NULL,
 #' @noRd
 app_bsky_graph_get_relationships <- function(actor, others = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getRelationships",
+    name = "bsky.social/xrpc/app.bsky.graph.getRelationships",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -179,7 +179,7 @@ app_bsky_graph_get_relationships <- function(actor, others = NULL, .token = NULL
 #' @noRd
 app_bsky_graph_get_starter_pack <- function(starterPack, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getStarterPack",
+    name = "bsky.social/xrpc/app.bsky.graph.getStarterPack",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -195,7 +195,7 @@ app_bsky_graph_get_starter_pack <- function(starterPack, .token = NULL, .return
 #' @noRd
 app_bsky_graph_get_starter_packs <- function(uris, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getStarterPacks",
+    name = "bsky.social/xrpc/app.bsky.graph.getStarterPacks",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -211,7 +211,7 @@ app_bsky_graph_get_starter_packs <- function(uris, .token = NULL, .return = c("j
 #' @noRd
 app_bsky_graph_get_suggested_follows_by_actor <- function(actor, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.getSuggestedFollowsByActor",
+    name = "bsky.social/xrpc/app.bsky.graph.getSuggestedFollowsByActor",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -227,7 +227,7 @@ app_bsky_graph_get_suggested_follows_by_actor <- function(actor, .token = NULL,
 #' @noRd
 app_bsky_graph_mute_actor <- function(actor, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.muteActor",
+    name = "bsky.social/xrpc/app.bsky.graph.muteActor",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -243,7 +243,7 @@ app_bsky_graph_mute_actor <- function(actor, .token = NULL, .return = c("json",
 #' @noRd
 app_bsky_graph_mute_actor_list <- function(list, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.muteActorList",
+    name = "bsky.social/xrpc/app.bsky.graph.muteActorList",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -259,7 +259,7 @@ app_bsky_graph_mute_actor_list <- function(list, .token = NULL, .return = c("jso
 #' @noRd
 app_bsky_graph_mute_thread <- function(root, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.muteThread",
+    name = "bsky.social/xrpc/app.bsky.graph.muteThread",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -275,7 +275,7 @@ app_bsky_graph_mute_thread <- function(root, .token = NULL, .return = c("json",
 #' @noRd
 app_bsky_graph_search_starter_packs <- function(q, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.searchStarterPacks",
+    name = "bsky.social/xrpc/app.bsky.graph.searchStarterPacks",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -291,7 +291,7 @@ app_bsky_graph_search_starter_packs <- function(q, limit = NULL, cursor = NULL,
 #' @noRd
 app_bsky_graph_unmute_actor <- function(actor, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.unmuteActor",
+    name = "bsky.social/xrpc/app.bsky.graph.unmuteActor",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -307,7 +307,7 @@ app_bsky_graph_unmute_actor <- function(actor, .token = NULL, .return = c("json"
 #' @noRd
 app_bsky_graph_unmute_actor_list <- function(list, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.unmuteActorList",
+    name = "bsky.social/xrpc/app.bsky.graph.unmuteActorList",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -323,7 +323,7 @@ app_bsky_graph_unmute_actor_list <- function(list, .token = NULL, .return = c("j
 #' @noRd
 app_bsky_graph_unmute_thread <- function(root, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.graph.unmuteThread",
+    name = "bsky.social/xrpc/app.bsky.graph.unmuteThread",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
