@@ -3,7 +3,7 @@
 #' @noRd
 app_bsky_notification_get_unread_count <- function(priority = NULL, seenAt = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.notification.getUnreadCount",
+    name = "bsky.social/xrpc/app.bsky.notification.getUnreadCount",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -17,9 +17,9 @@ app_bsky_notification_get_unread_count <- function(priority = NULL, seenAt = NUL
 #' app_bsky_notification_list_notifications
 #' Enumerate notifications for the requesting account. Requires auth.
 #' @noRd
-app_bsky_notification_list_notifications <- function(limit = NULL, priority = NULL, cursor = NULL, seenAt = NULL, .token = NULL, .return = c("json", "resp")) {
+app_bsky_notification_list_notifications <- function(reasons = NULL, limit = NULL, priority = NULL, cursor = NULL, seenAt = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.notification.listNotifications",
+    name = "bsky.social/xrpc/app.bsky.notification.listNotifications",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -35,7 +35,7 @@ app_bsky_notification_list_notifications <- function(limit = NULL, priority = NU
 #' @noRd
 app_bsky_notification_put_preferences <- function(priority, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.notification.putPreferences",
+    name = "bsky.social/xrpc/app.bsky.notification.putPreferences",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -51,7 +51,7 @@ app_bsky_notification_put_preferences <- function(priority, .token = NULL, .retu
 #' @noRd
 app_bsky_notification_register_push <- function(serviceDid, token, platform, appId, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.notification.registerPush",
+    name = "bsky.social/xrpc/app.bsky.notification.registerPush",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -67,7 +67,7 @@ app_bsky_notification_register_push <- function(serviceDid, token, platform, app
 #' @noRd
 app_bsky_notification_update_seen <- function(seenAt, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/app.bsky.notification.updateSeen",
+    name = "bsky.social/xrpc/app.bsky.notification.updateSeen",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
