@@ -3,7 +3,7 @@
 #' @noRd
 chat_bsky_actor_delete_account <- function(.token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/chat.bsky.actor.deleteAccount",
+    name = "bsky.social/xrpc/chat.bsky.actor.deleteAccount",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -19,7 +19,7 @@ chat_bsky_actor_delete_account <- function(.token = NULL, .return = c("json", "r
 #' @noRd
 chat_bsky_actor_export_account_data <- function(.token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/chat.bsky.actor.exportAccountData",
+    name = "bsky.social/xrpc/chat.bsky.actor.exportAccountData",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
