@@ -3,7 +3,7 @@
 #' @noRd
 com_atproto_label_query_labels <- function(uriPatterns, sources = NULL, limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.label.queryLabels",
+    name = "bsky.social/xrpc/com.atproto.label.queryLabels",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
