@@ -3,7 +3,7 @@
 #' @noRd
 com_atproto_moderation_create_report <- function(reasonType, subject, reason = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.moderation.createReport",
+    name = "bsky.social/xrpc/com.atproto.moderation.createReport",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
