@@ -3,7 +3,7 @@
 #' @noRd
 com_atproto_repo_apply_writes <- function(repo, writes, validate = NULL, swapCommit = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.applyWrites",
+    name = "bsky.social/xrpc/com.atproto.repo.applyWrites",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -19,7 +19,7 @@ com_atproto_repo_apply_writes <- function(repo, writes, validate = NULL, swapCom
 #' @noRd
 com_atproto_repo_create_record <- function(repo, collection, record, rkey = NULL, validate = NULL, swapCommit = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.createRecord",
+    name = "bsky.social/xrpc/com.atproto.repo.createRecord",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -35,7 +35,7 @@ com_atproto_repo_create_record <- function(repo, collection, record, rkey = NULL
 #' @noRd
 com_atproto_repo_delete_record <- function(repo, collection, rkey, swapRecord = NULL, swapCommit = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.deleteRecord",
+    name = "bsky.social/xrpc/com.atproto.repo.deleteRecord",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -51,7 +51,7 @@ com_atproto_repo_delete_record <- function(repo, collection, rkey, swapRecord =
 #' @noRd
 com_atproto_repo_describe_repo <- function(repo, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.describeRepo",
+    name = "bsky.social/xrpc/com.atproto.repo.describeRepo",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -67,7 +67,7 @@ com_atproto_repo_describe_repo <- function(repo, .token = NULL, .return = c("jso
 #' @noRd
 com_atproto_repo_get_record <- function(repo, collection, rkey, cid = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.getRecord",
+    name = "bsky.social/xrpc/com.atproto.repo.getRecord",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -83,7 +83,7 @@ com_atproto_repo_get_record <- function(repo, collection, rkey, cid = NULL, .tok
 #' @noRd
 com_atproto_repo_import_repo <- function(.token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.importRepo",
+    name = "bsky.social/xrpc/com.atproto.repo.importRepo",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -99,7 +99,7 @@ com_atproto_repo_import_repo <- function(.token = NULL, .return = c("json", "res
 #' @noRd
 com_atproto_repo_list_missing_blobs <- function(limit = NULL, cursor = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.listMissingBlobs",
+    name = "bsky.social/xrpc/com.atproto.repo.listMissingBlobs",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -113,9 +113,9 @@ com_atproto_repo_list_missing_blobs <- function(limit = NULL, cursor = NULL, .to
 #' com_atproto_repo_list_records
 #' List a range of records in a repository, matching a specific collection. Does not require auth.
 #' @noRd
-com_atproto_repo_list_records <- function(repo, collection, limit = NULL, cursor = NULL, rkeyStart = NULL, rkeyEnd = NULL, reverse = NULL, .token = NULL, .return = c("json", "resp")) {
+com_atproto_repo_list_records <- function(repo, collection, limit = NULL, cursor = NULL, reverse = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.listRecords",
+    name = "bsky.social/xrpc/com.atproto.repo.listRecords",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -131,7 +131,7 @@ com_atproto_repo_list_records <- function(repo, collection, limit = NULL, cursor
 #' @noRd
 com_atproto_repo_put_record <- function(repo, collection, rkey, record, validate = NULL, swapRecord = NULL, swapCommit = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.putRecord",
+    name = "bsky.social/xrpc/com.atproto.repo.putRecord",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -147,7 +147,7 @@ com_atproto_repo_put_record <- function(repo, collection, rkey, record, validate
 #' @noRd
 com_atproto_repo_upload_blob <- function(.token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/com.atproto.repo.uploadBlob",
+    name = "bsky.social/xrpc/com.atproto.repo.uploadBlob",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
