@@ -3,7 +3,7 @@
 #' @noRd
 tools_ozone_signature_find_correlation <- function(dids, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/tools.ozone.signature.findCorrelation",
+    name = "bsky.social/xrpc/tools.ozone.signature.findCorrelation",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -19,7 +19,7 @@ tools_ozone_signature_find_correlation <- function(dids, .token = NULL, .return
 #' @noRd
 tools_ozone_signature_find_related_accounts <- function(did, cursor = NULL, limit = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/tools.ozone.signature.findRelatedAccounts",
+    name = "bsky.social/xrpc/tools.ozone.signature.findRelatedAccounts",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
@@ -35,7 +35,7 @@ tools_ozone_signature_find_related_accounts <- function(did, cursor = NULL, limi
 #' @noRd
 tools_ozone_signature_search_accounts <- function(values, cursor = NULL, limit = NULL, .token = NULL, .return = c("json", "resp")) {
   make_request(
-    hostname = "bsky.social/xrpc/tools.ozone.signature.searchAccounts",
+    name = "bsky.social/xrpc/tools.ozone.signature.searchAccounts",
     params = as.list(match.call())[-1] |>
       purrr::imap(~ {
         eval(.x, envir = parent.frame())
